@@ -25,7 +25,9 @@ class Configuration(object):
                  "FLAME_ENABLED", "SERIALIZER", "SERIALIZERS_ACCEPTED", "LOGWIRE",
                  "METADATA", "REQUIRE_EXPOSE", "USE_MSG_WAITALL", "JSON_MODULE",
                  "MAX_RETRIES", "DILL_PROTOCOL_VERSION", "ITER_STREAMING", "ITER_STREAM_LIFETIME",
-                 "ITER_STREAM_LINGER")
+                 "ITER_STREAM_LINGER", "SSL", "SSL_REQUIRECLIENTCERT", "SSL_CACERTS",
+                 "SSL_SERVERCERT", "SSL_SERVERKEY", "SSL_SERVERKEYPASSWD",
+                 "SSL_CLIENTCERT", "SSL_CLIENTKEY", "SSL_CLIENTKEYPASSWD")
 
     def __init__(self):
         self.reset()
@@ -69,12 +71,21 @@ class Configuration(object):
             self.DILL_PROTOCOL_VERSION = -1
         self.METADATA = True  # get metadata from server on proxy connect
         self.REQUIRE_EXPOSE = True  # require @expose to make members remotely accessible (if False, everything is accessible)
-        self.USE_MSG_WAITALL = hasattr(socket, "MSG_WAITALL") and platform.system() != "Windows"      # not reliable on windows even though it is defined
+        self.USE_MSG_WAITALL = hasattr(socket, "MSG_WAITALL") and platform.system() != "Windows"  # waitall is not reliable on windows
         self.JSON_MODULE = "json"
         self.MAX_RETRIES = 0
         self.ITER_STREAMING = True
         self.ITER_STREAM_LIFETIME = 0.0
         self.ITER_STREAM_LINGER = 30.0
+        self.SSL = False
+        self.SSL_SERVERCERT = ""
+        self.SSL_SERVERKEY = ""
+        self.SSL_SERVERKEYPASSWD = ""
+        self.SSL_REQUIRECLIENTCERT = False
+        self.SSL_CLIENTCERT = ""
+        self.SSL_CLIENTKEY = ""
+        self.SSL_CLIENTKEYPASSWD = ""
+        self.SSL_CACERTS = ""
 
         if useenvironment:
             # process environment variables
