@@ -4,6 +4,7 @@ Miscellaneous utilities, and serializers.
 Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 """
 
+import array
 import sys
 import zlib
 import uuid
@@ -225,7 +226,7 @@ class SerializerBase(object):
         if serpent_too:
             try:
                 get_serializer_by_id(SerpentSerializer.serializer_id)
-                import serpent
+                import serpent      # @todo not needed?
 
                 def serpent_converter(obj, serializer, stream, level):
                     d = converter(obj)
@@ -243,7 +244,7 @@ class SerializerBase(object):
             del cls.__custom_class_to_dict_registry[clazz]
         try:
             get_serializer_by_id(SerpentSerializer.serializer_id)
-            import serpent
+            import serpent          # @todo not needed?
             serpent.unregister_class(clazz)
         except errors.ProtocolError:
             pass
@@ -532,13 +533,12 @@ class MarshalSerializer(SerializerBase):
     serializer_id = 3  # never change this
 
     def dumpsCall(self, obj, method, vargs, kwargs):
+        vargs = [self.convert_obj_into_marshallable(value) for value in vargs]
+        kwargs = {key: self.convert_obj_into_marshallable(value) for key, value in kwargs.items()}
         return marshal.dumps((obj, method, vargs, kwargs))
 
     def dumps(self, data):
-        try:
-            return marshal.dumps(data)
-        except (ValueError, TypeError):
-            return marshal.dumps(self.class_to_dict(data))
+        return marshal.dumps(self.convert_obj_into_marshallable(data))
 
     if sys.platform == "cli":
         def loadsCall(self, data):
@@ -567,6 +567,22 @@ class MarshalSerializer(SerializerBase):
             data = self._convertToBytes(data)
             return self.recreate_classes(marshal.loads(data))
 
+    marshalable_types = (str, int, float, type(None), bool, complex, bytes, bytearray,
+                         tuple, set, frozenset, list, dict)
+    if sys.version_info < (3, 0):
+        marshalable_types += (unicode,)
+
+    def convert_obj_into_marshallable(self, obj):
+        if isinstance(obj, self.marshalable_types):
+            return obj
+        if isinstance(obj, array.array):
+            if obj.typecode == 'c':
+                return obj.tostring()
+            if obj.typecode == 'u':
+                return obj.tounicode()
+            return obj.tolist()
+        return self.class_to_dict(obj)
+
     @classmethod
     def class_to_dict(cls, obj):
         if isinstance(obj, uuid.UUID):
@@ -655,6 +671,12 @@ class JsonSerializer(SerializerBase):
             return obj.isoformat()
         if isinstance(obj, decimal.Decimal):
             return str(obj)
+        if isinstance(obj, array.array):
+            if obj.typecode == 'c':
+                return obj.tostring()
+            if obj.typecode == 'u':
+                return obj.tounicode()
+            return obj.tolist()
         return self.class_to_dict(obj)
 
     @classmethod
@@ -707,6 +729,12 @@ class MsgpackSerializer(SerializerBase):
             return str(obj)
         if isinstance(obj, numbers.Number):
             return msgpack.ExtType(0x31, str(obj).encode("ascii"))     # long
+        if isinstance(obj, array.array):
+            if obj.typecode == 'c':
+                return obj.tostring()
+            if obj.typecode == 'u':
+                return obj.tounicode()
+            return obj.tolist()
         return self.class_to_dict(obj)
 
     def object_hook(self, obj):
@@ -797,19 +825,22 @@ try:
     else:
         ver = serpent.__version__
     ver = tuple(map(int, ver.split(".")))
-    if ver < (1, 24):  # serpent 1.24 required
-        raise RuntimeError("requires serpent 1.24 or better")
+    if ver < (1, 27):
+        raise RuntimeError("requires serpent 1.27 or later")
     _ser = SerpentSerializer()
     _serializers["serpent"] = _ser
     _serializers_by_id[_ser.serializer_id] = _ser
 except ImportError:
     log.warning("serpent serializer is not available")
-    pass
 try:
     import msgpack
-    _ser = MsgpackSerializer()
-    _serializers["msgpack"] = _ser
-    _serializers_by_id[_ser.serializer_id] = _ser
+    if msgpack.version < (0, 5, 2):
+        import warnings
+        warnings.warn("msgpack serializer unavailable. requires msgpack 0.5.2+, found " + str(msgpack.version))
+    else:
+        _ser = MsgpackSerializer()
+        _serializers["msgpack"] = _ser
+        _serializers_by_id[_ser.serializer_id] = _ser
 except ImportError:
     pass
 del _ser
